@@ -60,7 +60,7 @@ class Peek
 
     def base?
       # VrpResourceAllocationInfo is removed in 6.7, so base will no longer generated
-      return false if @name == "ResourceAllocationInfo"
+      return false if ["ResourceAllocationInfo", "FaultDomainId"].include?(@name)
 
       return !children.empty?
     end
